@@ -24,28 +24,28 @@ sub scan_dir {
 
 die "Usage: $0 <dir1> <dir2>\n" unless @ARGV == 2;
 
-my ($dir1, $dir2) = @ARGV;
-my %files1 = scan_dir($dir1);
-my %files2 = scan_dir($dir2);
+my ($dir_lhs, $dir_rhs) = @ARGV;
+my %files_lhs = scan_dir($dir_lhs);
+my %files_rhs = scan_dir($dir_rhs);
 
 my @different;
-for my $f (keys_intersection %files1, %files2) {
-  push @different, $f if $files1{$f} != $files2{$f};
+foreach my $path (keys_intersection %files_lhs, %files_rhs) {
+  push @different, $path if $files_lhs{$path} != $files_rhs{$path};
 }
 
-my @only_left  = keys_difference %files1, %files2;
-my @only_right = keys_difference %files2, %files1;
+my @only_lhs = keys_difference %files_lhs, %files_rhs;
+my @only_rhs = keys_difference %files_rhs, %files_lhs;
 
-say "\nOnly in $dir1: ", scalar @only_left;
-say "  $_" for sort @only_left;
+say "\nOnly in $dir_lhs: ", scalar @only_lhs;
+say "  $_" for sort @only_lhs;
 
-say "\nOnly in $dir2: ", scalar @only_right;
-say "  $_" for sort @only_right;
+say "\nOnly in $dir_rhs: ", scalar @only_rhs;
+say "  $_" for sort @only_rhs;
 
 say "\nDifferent sizes: ", scalar @different;
 say "  $_" for sort @different;
 
 say "\nSummary: ", 
-      scalar @only_left, " + ",
-      scalar @only_right, " + ",
+      scalar @only_lhs, " + ",
+      scalar @only_rhs, " + ",
       scalar @different, " differences";
